Package 'q3ML'

Title: Open and Parse SRM mzML Files from Thermo Triple Quadrupole Instruments
Description: Parses selective reaction monitoring (SRM) mzML chromatograms exported from Thermo triple quadrupole instruments. The package is intended as a fallback for newer ProteoWizard-generated mzML files where chromatogram data cannot be decoded through 'mzR', while preserving output structures that are easy to compare with 'mzR' headers and chromatograms.
Authors: Tom Wilson [aut, cre]
Maintainer: Tom Wilson <[email protected]>
License: GPL (>= 3)
Version: 0.1.0
Built: 2026-05-19 22:16:10 UTC
Source: https://github.com/wilsontom/q3ML

Help Index


Open .mzML File

Description

Open and parse a .mzML file containing Selective Reaction Monitoring (SRM) Mass Spectrometry (MS) data using xml2

Usage

openFile(mzml_file)

Arguments

mzml_file

the absolute file path of a valid .mzML file

Value

a list of two elements containing peaks and header